@@ -1,6 +1,6 @@
 """Base class for workflow scripts."""
 from abc import ABC, abstractmethod
-from git_workflow.utils import cmd
+from cmd_utils import cmd
 from git_workflow.utils.configs import Configs
 
 
